Learn R Programming

spuRs (version 1.0.5)

mean.transectHolder: Function to compute the mean dispersal distance along a transect of seed traps.

Description

This function computes the mean dispersal distance along a transect of seed traps.

Usage

## S3 method for class transectHolder 
## S3 method for class 'transectHolder':
mean(x, \dots)

Arguments

x
an object representing a transect of seed traps.
...
further arguments passed to or from other methods.

Value

  • The mean seed dispersal distance is returned.

References

Jones, O.D., R. Maillardet, and A.P. Robinson. 2009. An Introduction to Scientific Programming and Simulation, Using R. Chapman And Hall/CRC.

See Also

transectHolder

Examples

Run this code
transect.1 <- trapTransect(distances = 1:4,
                        seed.counts = c(4, 3, 2, 0))
transect.2 <- trapTransect(distances = 1:3,
                        seed.counts = c(3, 2, 1))
transect.3 <- trapTransect(distances=(1:5)/2,
                        seed.counts = c(3, 4, 2, 3, 1))
allTraps <- transectHolder(transect.1, transect.2, transect.3,
                           family="Weibull")

mean(allTraps)

Run the code above in your browser using DataLab