Learn R Programming

spuRs (version 1.0.5)

mean.trapTransect: Function to compute the mean dispersal distance along a transect of seed traps.

Description

This function computes the mean dispersal distance along a transect of seed traps.

Usage

## S3 method for class trapTransect 
## S3 method for class 'trapTransect':
mean(x, \dots)

Arguments

x
an object representing a transect of seed traps.
...
further arguments passed to or from other methods.

Value

  • The mean seed dispersal distance is returned.

References

Jones, O.D., R. Maillardet, and A.P. Robinson. 2009. An Introduction to Scientific Programming and Simulation, Using R. Chapman And Hall/CRC.

See Also

trapTransect

Examples

Run this code
s1 <- trapTransect(distances = 1:4, seed.count = c(4, 3, 2, 0))
mean(s1)

Run the code above in your browser using DataLab