ufc: Upper Flat Creek forest cruise tree data
Description
These are a subset of the tree measurement data from the
Upper Flat Creek unit of the University of Idaho Experimental
Forest, which was measured in 1991.source
The data are provided courtesy of Harold Osborne and Ross
Appelgren of the University of Idaho Experimental Forest.Details
The inventory was based on variable radius plots with 6.43 sq. m.
per ha. BAF (Basal Area Factor). The forest stand was 121.5 ha.
This version of the data omits errors, trees with missing heights,
and uncommon species. The four species are Douglas-fir, grand fir,
western red cedar, and western larch.References
Jones, O.D., R. Maillardet, and A.P. Robinson. 2009. An Introduction
to Scientific Programming and Simulation, Using R. Chapman And Hall/CRC.