ufc.plots: Upper Flat Creek forest cruise plot data
Description
These are a subset of the plot measurement data from the
Upper Flat Creek unit of the University of Idaho Experimental
Forest, which was measured in 1991.
Format
A data frame with 144 observations on the following 6 variables.
- plot
- plot label
- north.n
- northerly plot count
- east.n
- easterly plot count
- north
- northerly coordinate
- east
- easterly coordinate
- vol.m3.ha
- total above-ground merchantable volume, in
cubic metres per hectare.
The data are provided courtesy of Harold Osborne and Ross
Appelgren of the University of Idaho Experimental Forest.References
Jones, O.D., R. Maillardet, and A.P. Robinson. 2009. An Introduction
to Scientific Programming and Simulation, Using R. Chapman And Hall/CRC.