Learn R Programming

spuRs (version 1.0.5)

spuRs-package: "Introduction to Scientific Programming and Simulation Using R."

Description

This package provides scripts, functions and datasets for the book "Introduction to Scientific Programming and Simulation Using R."

Arguments

Details

ll{ Package: spuRs Type: Package Version: 1.0 Date: 2008-08-12 License: TBA LazyLoad: yes } The datasets are: kew, treeg, trees, ufc.plots, and ufc.

The main functions are: bisection, fixedpoint, fixedpoint_show, newtonraphson, newtonraphson_show, prime, primesieve, and vol.m3.

We also provide functions relevant to the seedtrap case study: mean and print functions, an sd function, simulate, fitDistances, and constructors. See Chapters 8 and 21 for more details.

Type ? to learn more about these objects, e.g. ?ufc

References

Jones, O.D., R.J. Maillardet, and A.P. Robinson. 2009. Introduction to Scientific Programming and Simulation Using R. Chapman And Hall/CRC.