Learn R Programming

spuRs (version 1.0.5)

ufc.plots: Upper Flat Creek forest cruise plot data

Description

These are a subset of the plot measurement data from the Upper Flat Creek unit of the University of Idaho Experimental Forest, which was measured in 1991.

Usage

data(ufc.plots)

Arguments

source

The data are provided courtesy of Harold Osborne and Ross Appelgren of the University of Idaho Experimental Forest.

References

Jones, O.D., R. Maillardet, and A.P. Robinson. 2009. An Introduction to Scientific Programming and Simulation, Using R. Chapman And Hall/CRC.

See Also

ufc

Examples

Run this code
data(ufc.plots)

Run the code above in your browser using DataLab