ufc.plots: Upper Flat Creek forest cruise plot data
Description
These are a subset of the plot measurement data from the
Upper Flat Creek unit of the University of Idaho Experimental
Forest, which was measured in 1991.source
The data are provided courtesy of Harold Osborne and Ross
Appelgren of the University of Idaho Experimental Forest.References
Jones, O.D., R. Maillardet, and A.P. Robinson. 2009. An Introduction
to Scientific Programming and Simulation, Using R. Chapman And Hall/CRC.