Learn R Programming

spuRs (version 1.0.5)

vol.m3: Function to compute the volume of a tree bole assuming a particular shape.

Description

This function computes the volume of a tree bole given its basal diameter and length, assuming that the bole is a frustum of a geometric solid.

Usage

vol.m3(dbh.cm, height.m, multiplier = 0.5)

Arguments

dbh.cm
basal diameter in cm.
height.m
height in m.
multiplier
shape, expressed as a multiplier.

Value

  • The volume is returned, in units of cubic metres.

Details

Commonly-used shapes are:
  • 1/3
{conoid} 1/2{second-degree parabaloid} 1{cylinder}

Examples

Run this code
vol.m3(30, 30)
vol.m3(30, 30, 1)

Run the code above in your browser using DataLab